searchData={"items":[{"type":"module","title":"StompClient","doc":"Custom STOMP protocol client implementation for Elixir.\n\nThis module provides a GenServer-based STOMP client with precise control over message formatting, \nespecially content-length headers. It features automatic reconnection, heartbeat support, and \ncallback-based message handling.","ref":"StompClient.html"},{"type":"module","title":"Features - StompClient","doc":"- **Custom Message Formatting**: Control over content-length headers (can omit content-length for SEND frames)\n- **Automatic Reconnection**: Automatic reconnection with configurable retry intervals\n- **Heartbeat Support**: Built-in heartbeat mechanism to keep connections alive\n- **Callback-based Handling**: Process-based callback system for handling connection events and messages\n- **STOMP 1.2 Compatible**: Full support for STOMP 1.2 protocol\n- **Subscription Management**: Easy subscription and unsubscription management","ref":"StompClient.html#module-features"},{"type":"module","title":"Usage - StompClient","doc":"The basic workflow involves:\n\n1. Start a callback handler process\n2. Connect to the STOMP server\n3. Subscribe to destinations\n4. Send/receive messages\n5. Disconnect when done","ref":"StompClient.html#module-usage"},{"type":"module","title":"Example - StompClient","doc":"# Define a callback handler\n    defmodule MyHandler do\n      use GenServer\n      \n      def start_link(_), do: GenServer.start_link(__MODULE__, nil, name: __MODULE__)\n      def init(_), do: {:ok, %{}}\n      \n      def handle_info({:stomp_client, :on_connect, _frame}, state) do\n        IO.puts(\"Connected!\")\n        {:noreply, state}\n      end\n      \n      def handle_info({:stomp_client, :on_message, message}, state) do\n        IO.puts(\"Received message\")\n        {:noreply, state}\n      end\n      \n      def handle_info(_, state), do: {:noreply, state}\n    end\n\n    # Start handler and connect  \n    {:ok, _} = MyHandler.start_link(nil)\n    {:ok, client} = StompClient.connect([\n      host: \"localhost\",\n      port: 61613,\n      username: \"guest\",\n      password: \"guest\"\n    ], callback_handler: MyHandler)\n\n    # Use the client\n    StompClient.subscribe(client, \"/queue/test\")\n    StompClient.send(client, \"/queue/test\", \"Hello World!\")\n    StompClient.disconnect(client)","ref":"StompClient.html#module-example"},{"type":"module","title":"Callback Messages - StompClient","doc":"Your callback handler will receive these message types:\n\n- `{:stomp_client, :on_connect, frame}` - When successfully connected\n- `{:stomp_client, :on_message, message}` - When a message is received  \n- `{:stomp_client, :on_disconnect, nil}` - When disconnected\n- `{:stomp_client, :on_connect_error, error}` - When connection fails\n- `{:stomp_client, :on_send, frame}` - When a frame is sent (optional)","ref":"StompClient.html#module-callback-messages"},{"type":"function","title":"StompClient.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StompClient.html#child_spec/1"},{"type":"function","title":"StompClient.connect/2","doc":"Connects to a STOMP server with callback handler.\n\nThis is a convenience function that combines `start_link/1` with callback handler setup.","ref":"StompClient.html#connect/2"},{"type":"function","title":"Parameters - StompClient.connect/2","doc":"- `opts` - Connection options (keyword list or map)\n- `callback_handler` - Process to receive callback messages","ref":"StompClient.html#connect/2-parameters"},{"type":"function","title":"Examples - StompClient.connect/2","doc":"{:ok, client} = StompClient.connect([\n      host: \"localhost\",\n      port: 61613,\n      username: \"guest\", \n      password: \"guest\"\n    ], callback_handler: MyHandler)","ref":"StompClient.html#connect/2-examples"},{"type":"function","title":"StompClient.disconnect/1","doc":"Disconnects from the STOMP server and stops the client.","ref":"StompClient.html#disconnect/1"},{"type":"function","title":"Parameters - StompClient.disconnect/1","doc":"- `pid` - The STOMP client process","ref":"StompClient.html#disconnect/1-parameters"},{"type":"function","title":"Returns - StompClient.disconnect/1","doc":"- `:ok` always","ref":"StompClient.html#disconnect/1-returns"},{"type":"function","title":"Examples - StompClient.disconnect/1","doc":"StompClient.disconnect(client)","ref":"StompClient.html#disconnect/1-examples"},{"type":"function","title":"StompClient.send/4","doc":"Sends a message to a STOMP destination.","ref":"StompClient.html#send/4"},{"type":"function","title":"Parameters - StompClient.send/4","doc":"- `pid` - The STOMP client process\n- `destination` - STOMP destination (e.g., \"/queue/test\" or \"/topic/news\")\n- `body` - Message body as string\n- `headers` - Optional list of additional headers as tuples","ref":"StompClient.html#send/4-parameters"},{"type":"function","title":"Returns - StompClient.send/4","doc":"- `:ok` on success\n- `{:error, :not_connected}` if client is not connected\n- `{:error, reason}` on other errors","ref":"StompClient.html#send/4-returns"},{"type":"function","title":"Examples - StompClient.send/4","doc":"# Simple message\n    StompClient.send(client, \"/queue/test\", \"Hello World!\")\n    \n    # Message with custom headers  \n    StompClient.send(client, \"/queue/test\", \"Hello\", [\n      {\"priority\", \"5\"},\n      {\"custom-header\", \"value\"}\n    ])","ref":"StompClient.html#send/4-examples"},{"type":"function","title":"StompClient.start_link/1","doc":"Starts a STOMP client process.","ref":"StompClient.html#start_link/1"},{"type":"function","title":"Parameters - StompClient.start_link/1","doc":"- `opts` - Connection options as keyword list or map","ref":"StompClient.html#start_link/1-parameters"},{"type":"function","title":"Options - StompClient.start_link/1","doc":"- `:host` - STOMP server hostname (required)\n- `:port` - STOMP server port (default: 61613)\n- `:username` or `:login` - Authentication username  \n- `:password` or `:passcode` - Authentication password\n- `:callback_handler` - Process to receive callback messages (required)","ref":"StompClient.html#start_link/1-options"},{"type":"function","title":"Examples - StompClient.start_link/1","doc":"{:ok, client} = StompClient.start_link([\n      host: \"localhost\",\n      port: 61613,\n      username: \"guest\",\n      password: \"guest\",\n      callback_handler: MyHandler\n    ])","ref":"StompClient.html#start_link/1-examples"},{"type":"function","title":"StompClient.subscribe/3","doc":"Subscribes to a STOMP destination.","ref":"StompClient.html#subscribe/3"},{"type":"function","title":"Parameters - StompClient.subscribe/3","doc":"- `pid` - The STOMP client process\n- `destination` - STOMP destination to subscribe to\n- `opts` - Optional subscription options","ref":"StompClient.html#subscribe/3-parameters"},{"type":"function","title":"Options - StompClient.subscribe/3","doc":"- `:id` - Custom subscription ID (auto-generated if not provided)\n- `:selector` - Message selector for filtering","ref":"StompClient.html#subscribe/3-options"},{"type":"function","title":"Returns - StompClient.subscribe/3","doc":"- `:ok` on success\n- `{:error, :not_connected}` if client is not connected\n- `{:error, reason}` on other errors","ref":"StompClient.html#subscribe/3-returns"},{"type":"function","title":"Examples - StompClient.subscribe/3","doc":"# Simple subscription\n    StompClient.subscribe(client, \"/queue/test\")\n    \n    # Subscription with selector\n    StompClient.subscribe(client, \"/queue/test\", selector: \"priority > 5\")\n    \n    # Subscription with custom ID\n    StompClient.subscribe(client, \"/queue/test\", id: \"my-subscription\")","ref":"StompClient.html#subscribe/3-examples"},{"type":"function","title":"StompClient.unsubscribe/2","doc":"Unsubscribes from a STOMP destination.","ref":"StompClient.html#unsubscribe/2"},{"type":"function","title":"Parameters - StompClient.unsubscribe/2","doc":"- `pid` - The STOMP client process\n- `destination` - STOMP destination to unsubscribe from","ref":"StompClient.html#unsubscribe/2-parameters"},{"type":"function","title":"Returns - StompClient.unsubscribe/2","doc":"- `:ok` on success\n- `{:error, :not_connected}` if client is not connected  \n- `{:error, :not_subscribed}` if not subscribed to destination\n- `{:error, reason}` on other errors","ref":"StompClient.html#unsubscribe/2-returns"},{"type":"function","title":"Examples - StompClient.unsubscribe/2","doc":"StompClient.unsubscribe(client, \"/queue/test\")","ref":"StompClient.html#unsubscribe/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}